==> eiffelstudio-16.05.tar: F_code/C3/pa117.c <==
/*
 * Code for class PACKED_BOOLEANS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "pa117.h"
#include "eif_built_in.h"
#include "eif_helpers.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PACKED_BOOLEANS}.make */
void F128_2336 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {1694,1916,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSP2(typres0.id,0,(EIF_INTEGER_32) (((EIF_INTEGER_32) 1L) + (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 32L))),sizeof(EIF_INTEGER_32), EIF_TRUE);
	}
	F1695_16165(RTCW(tr1), ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (((EIF_INTEGER_32) 1L) + (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 32L))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PACKED_BOOLEANS}.item */
EIF_BOOLEAN F128_2337 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = 
		/* INLINED CODE (SPECIAL.item) */
		*((EIF_INTEGER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 32L))))
		/* END INLINED CODE */;
	Result = eif_bit_test(EIF_INTEGER_32,ti4_1,(EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 32L)));
	RTLE;
	return Result;
}

/* {PACKED_BOOLEANS}.valid_index */
EIF_BOOLEAN F128_2338 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	Result = '\0';
	if ((EIF_BOOLEAN) (((EIF_INTEGER_32) 0L) <= arg1)) {
		{
			/* INLINED CODE (upper) */
			ti4_1 = (EIF_INTEGER_32)  0;
			ti4_1 = F128_2342(Current);
			ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L));
			/* END INLINED CODE */
		}
		Result = (EIF_BOOLEAN) (arg1 <= ti4_1);
	}
	RTLE;
	return Result;
}

/* {PACKED_BOOLEANS}.is_equal */
EIF_BOOLEAN F128_2339 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,loc1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTGC;
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(arg1 == Current);
	if ((EIF_BOOLEAN) !Result) {
		loc1 = *(EIF_REFERENCE *)(Current);
		loc2 = *(EIF_REFERENCE *)(RTCW(arg1));
		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc1);
		ti4_2 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc2);
		if ((EIF_BOOLEAN)(ti4_1 == ti4_2)) {
			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc1);
			Result = F1695_16180(RTCW(loc1), loc2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
		}
	}
	RTLE;
	return Result;
}

/* {PACKED_BOOLEANS}.upper */
EIF_INTEGER_32 F128_2341 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		/* INLINED CODE (count) */
		ti4_1 = (EIF_INTEGER_32)  0;
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
		ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 * ((EIF_INTEGER_32) 32L));
		/* END INLINED CODE */
	}
	Result = ti4_1;
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result - ((EIF_INTEGER_32) 1L));
	RTLE;
	return Result;
}

/* {PACKED_BOOLEANS}.count */
EIF_INTEGER_32 F128_2342 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result * ((EIF_INTEGER_32) 32L));
	RTLE;
	return Result;
}

/* {PACKED_BOOLEANS}.put */
void F128_2344 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg2 / ((EIF_INTEGER_32) 32L));
	if (arg1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(Current);
		ti4_1 = 
			/* INLINED CODE (SPECIAL.item) */
			*((EIF_INTEGER_32 *)RTCW(tr2) + (loc1))
			/* END INLINED CODE */;
		ti4_2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		ti4_2 = eif_bit_shift_left(ti4_2,(EIF_INTEGER_32) (arg2 % ((EIF_INTEGER_32) 32L)));
		ti4_1 = eif_bit_or(ti4_1,ti4_2);
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_INTEGER_32 *)tr1 + (loc1)) = ti4_1;
		/* END INLINED CODE */
		;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(Current);
		ti4_1 = 
			/* INLINED CODE (SPECIAL.item) */
			*((EIF_INTEGER_32 *)RTCW(tr2) + (loc1))
			/* END INLINED CODE */;
		ti4_2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		ti4_2 = eif_bit_shift_left(ti4_2,(EIF_INTEGER_32) (arg2 % ((EIF_INTEGER_32) 32L)));
		ti4_2 = eif_bit_not(ti4_2);
		ti4_1 = eif_bit_and(ti4_1,ti4_2);
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_INTEGER_32 *)tr1 + (loc1)) = ti4_1;
		/* END INLINED CODE */
		;
	}
	RTLE;
}

/* {PACKED_BOOLEANS}.force */
void F128_2345 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		/* INLINED CODE (count) */
		ti4_1 = (EIF_INTEGER_32)  0;
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
		ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 * ((EIF_INTEGER_32) 32L));
		/* END INLINED CODE */
	}
	loc1 = ti4_1;
	if ((EIF_BOOLEAN) (arg2 >= loc1)) {
		ti4_1 = eif_max_int32 (arg2,(EIF_INTEGER_32) (loc1 + (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 * ((EIF_INTEGER_32) 30L)) / ((EIF_INTEGER_32) 100L))));
		F128_2347(Current, ti4_1);
	}
	F128_2344(Current, arg1, arg2);
	RTLE;
}

/* {PACKED_BOOLEANS}.include */
void F128_2346 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,loc3);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	loc2 = *(EIF_REFERENCE *)(Current);
	loc3 = *(EIF_REFERENCE *)(RTCW(arg1));
	loc1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc3);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 <= ((EIF_INTEGER_32) 0L))) break;
		loc1--;
		ti4_1 = 
			/* INLINED CODE (SPECIAL.item) */
			*((EIF_INTEGER_32 *)RTCW(loc2) + (loc1))
			/* END INLINED CODE */;
		/* INLINED CODE (SPECIAL.item) */
		ti4_3 = *((EIF_INTEGER_32 *)loc3 + (loc1));
		/* END INLINED CODE */
		ti4_2 = ti4_3;
		ti4_1 = eif_bit_or(ti4_1,ti4_2);
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_INTEGER_32 *)loc2 + (loc1)) = ti4_1;
		/* END INLINED CODE */
		;
	}
	RTLE;
}

/* {PACKED_BOOLEANS}.resize */
void F128_2347 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (((EIF_INTEGER_32) 1L) + (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 32L)));
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
	if ((EIF_BOOLEAN) (loc1 > ti4_1)) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = F1695_16200(RTCW(tr1), ((EIF_INTEGER_32) 0L), loc1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {PACKED_BOOLEANS}.clear_all */
void F128_2348 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	tr2 = *(EIF_REFERENCE *)(Current);
	{
		/* INLINED CODE (upper) */
		ti4_1 = (EIF_INTEGER_32)  0;
		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr2);
		ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L));
		/* END INLINED CODE */
	}
	ti4_1 = ti4_1;
	F1695_16186(RTCW(tr1), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
	RTLE;
}

/* {PACKED_BOOLEANS}.copy */
void F128_2349 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 != Current)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
		tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (tr1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {PACKED_BOOLEANS}.area */
EIF_REFERENCE F128_2351 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


void EIF_Minit117 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C3/pa117.c <==
/*
 * Code for class PACKED_BOOLEANS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "pa117.h"
#include "eif_built_in.h"
#include "eif_helpers.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PACKED_BOOLEANS}.make */
void F128_2350 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {1813,1977,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSP2(typres0.id,0,(EIF_INTEGER_32) (((EIF_INTEGER_32) 1L) + (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 32L))),sizeof(EIF_INTEGER_32), EIF_TRUE);
	}
	F1814_17342(RTCW(tr1), ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (((EIF_INTEGER_32) 1L) + (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 32L))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PACKED_BOOLEANS}.item */
EIF_BOOLEAN F128_2351 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = 
		/* INLINED CODE (SPECIAL.item) */
		*((EIF_INTEGER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 32L))))
		/* END INLINED CODE */;
	Result = eif_bit_test(EIF_INTEGER_32,ti4_1,(EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 32L)));
	RTLE;
	return Result;
}

/* {PACKED_BOOLEANS}.valid_index */
EIF_BOOLEAN F128_2352 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	Result = '\0';
	if ((EIF_BOOLEAN) (((EIF_INTEGER_32) 0L) <= arg1)) {
		{
			/* INLINED CODE (upper) */
			ti4_1 = (EIF_INTEGER_32)  0;
			ti4_1 = F128_2356(Current);
			ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L));
			/* END INLINED CODE */
		}
		Result = (EIF_BOOLEAN) (arg1 <= ti4_1);
	}
	RTLE;
	return Result;
}

/* {PACKED_BOOLEANS}.is_equal */
EIF_BOOLEAN F128_2353 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,loc1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTGC;
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(arg1 == Current);
	if ((EIF_BOOLEAN) !Result) {
		loc1 = *(EIF_REFERENCE *)(Current);
		loc2 = *(EIF_REFERENCE *)(RTCW(arg1));
		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc1);
		ti4_2 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc2);
		if ((EIF_BOOLEAN)(ti4_1 == ti4_2)) {
			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc1);
			Result = F1814_17357(RTCW(loc1), loc2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
		}
	}
	RTLE;
	return Result;
}

/* {PACKED_BOOLEANS}.upper */
EIF_INTEGER_32 F128_2355 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		/* INLINED CODE (count) */
		ti4_1 = (EIF_INTEGER_32)  0;
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
		ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 * ((EIF_INTEGER_32) 32L));
		/* END INLINED CODE */
	}
	Result = ti4_1;
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result - ((EIF_INTEGER_32) 1L));
	RTLE;
	return Result;
}

/* {PACKED_BOOLEANS}.count */
EIF_INTEGER_32 F128_2356 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result * ((EIF_INTEGER_32) 32L));
	RTLE;
	return Result;
}

/* {PACKED_BOOLEANS}.put */
void F128_2358 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg2 / ((EIF_INTEGER_32) 32L));
	if (arg1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(Current);
		ti4_1 = 
			/* INLINED CODE (SPECIAL.item) */
			*((EIF_INTEGER_32 *)RTCW(tr2) + (loc1))
			/* END INLINED CODE */;
		ti4_2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		ti4_2 = eif_bit_shift_left(ti4_2,(EIF_INTEGER_32) (arg2 % ((EIF_INTEGER_32) 32L)));
		ti4_1 = eif_bit_or(ti4_1,ti4_2);
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_INTEGER_32 *)RTCW(tr1) + (loc1)) = ti4_1;
		/* END INLINED CODE */
		;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(Current);
		ti4_1 = 
			/* INLINED CODE (SPECIAL.item) */
			*((EIF_INTEGER_32 *)RTCW(tr2) + (loc1))
			/* END INLINED CODE */;
		ti4_2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		ti4_2 = eif_bit_shift_left(ti4_2,(EIF_INTEGER_32) (arg2 % ((EIF_INTEGER_32) 32L)));
		ti4_2 = eif_bit_not(ti4_2);
		ti4_1 = eif_bit_and(ti4_1,ti4_2);
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_INTEGER_32 *)RTCW(tr1) + (loc1)) = ti4_1;
		/* END INLINED CODE */
		;
	}
	RTLE;
}

/* {PACKED_BOOLEANS}.force */
void F128_2359 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		/* INLINED CODE (count) */
		ti4_1 = (EIF_INTEGER_32)  0;
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
		ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 * ((EIF_INTEGER_32) 32L));
		/* END INLINED CODE */
	}
	loc1 = ti4_1;
	if ((EIF_BOOLEAN) (arg2 >= loc1)) {
		ti4_1 = eif_max_int32 (arg2,(EIF_INTEGER_32) (loc1 + (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 * ((EIF_INTEGER_32) 30L)) / ((EIF_INTEGER_32) 100L))));
		F128_2361(Current, ti4_1);
	}
	F128_2358(Current, arg1, arg2);
	RTLE;
}

/* {PACKED_BOOLEANS}.include */
void F128_2360 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,loc3);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	loc2 = *(EIF_REFERENCE *)(Current);
	loc3 = *(EIF_REFERENCE *)(RTCW(arg1));
	loc1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc3);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 <= ((EIF_INTEGER_32) 0L))) break;
		loc1--;
		ti4_1 = 
			/* INLINED CODE (SPECIAL.item) */
			*((EIF_INTEGER_32 *)RTCW(loc2) + (loc1))
			/* END INLINED CODE */;
		/* INLINED CODE (SPECIAL.item) */
		ti4_3 = *((EIF_INTEGER_32 *)RTCW(loc3) + (loc1));
		/* END INLINED CODE */
		ti4_2 = ti4_3;
		ti4_1 = eif_bit_or(ti4_1,ti4_2);
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_INTEGER_32 *)RTCW(loc2) + (loc1)) = ti4_1;
		/* END INLINED CODE */
		;
	}
	RTLE;
}

/* {PACKED_BOOLEANS}.resize */
void F128_2361 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (((EIF_INTEGER_32) 1L) + (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 32L)));
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
	if ((EIF_BOOLEAN) (loc1 > ti4_1)) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = F1814_17377(RTCW(tr1), ((EIF_INTEGER_32) 0L), loc1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {PACKED_BOOLEANS}.clear_all */
void F128_2362 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	tr2 = *(EIF_REFERENCE *)(Current);
	{
		/* INLINED CODE (upper) */
		ti4_1 = (EIF_INTEGER_32)  0;
		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr2);
		ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L));
		/* END INLINED CODE */
	}
	ti4_1 = ti4_1;
	F1814_17363(RTCW(tr1), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
	RTLE;
}

/* {PACKED_BOOLEANS}.copy */
void F128_2363 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 != Current)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
		tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (tr1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {PACKED_BOOLEANS}.area */
EIF_REFERENCE F128_2365 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


void EIF_Minit117 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
